@@ -876,6 +876,7 @@ def test_filler(tmp_path):
         assert filled_event_page is event_page
 
     with pytest.warns(UserWarning):
+        # warnings because inplace is not specified
         filler = event_model.Filler(reg)
 
     class OtherDummyHandler:
@@ -943,7 +944,7 @@ def test_filler(tmp_path):
             filler('event', event)
 
     with pytest.raises(event_model.MismatchedDataKeys):
-        with event_model.Filler(reg) as filler:
+        with event_model.Filler(reg, inplace=False) as filler:
             filler('start', run_bundle.start_doc)
             filler('descriptor', desc_bundle.descriptor_doc)
             filler('descriptor', desc_bundle_baseline.descriptor_doc)
@@ -1066,7 +1067,6 @@ def test_run_router(tmp_path):
         collected.append((name, doc))
 
     def all_factory(name, doc):
-        collector(name, doc)
         return [collector], []
 
     rr = event_model.RunRouter([all_factory])
@@ -1095,6 +1095,51 @@ def test_run_router(tmp_path):
     assert unexpected_item not in collected
     collected.clear()
 
+    # Test factory that expects old (pre-1.14.0) RunRouter behavior.
+
+    collected_header_docs = {}
+
+    class LocalException3(Exception):
+        ...
+
+    def header_collector(name, doc):
+        if name in ('start', 'stop', 'descriptor'):
+            key = (name, doc['uid'])
+            if key in collected_header_docs:
+                raise LocalException3
+            collected_header_docs[key] = doc
+
+    def all_factory(name, doc):
+        header_collector(name, doc)
+        return [header_collector], []
+
+    rr = event_model.RunRouter([all_factory])
+    with pytest.warns(UserWarning, match='1.14.0'):
+        for name, doc in docs:
+            rr(name, doc)
+
+    collected_header_docs.clear()
+
+    # Test subfactory that expects old (pre-1.14.0) RunRouter behavior.
+
+    def factory_with_subfactory_only(name, doc):
+        header_collector(name, doc)
+
+        def subfactory(name, doc):
+            if doc.get('name') == 'baseline':
+                header_collector(name, doc)
+                return [header_collector]
+            return []
+
+        return [], [subfactory]
+
+    rr = event_model.RunRouter([factory_with_subfactory_only])
+    with pytest.warns(UserWarning, match='1.14.0'):
+        for name, doc in docs:
+            rr(name, doc)
+
+    collected_header_docs.clear()
+
     # Test RunRouter with handler_registry.
 
     class FakeTiffHandler:
@@ -1236,3 +1281,13 @@ def test_round_trip_datum_page_with_empty_data():
 
     page_again = event_model.pack_datum_page(*datums)
     assert page_again == datum_page
+
+
+def test_register_coersion():
+    # Re-registration should be fine.
+    assert 'as_is' in event_model._coersion_registry  # implementation detail
+    event_model.register_coersion('as_is', event_model.as_is)
+
+    # but registering something different to the same name should raise.
+    with pytest.raises(event_model.EventModelValueError):
+        event_model.register_coersion('as_is', object)
